@@ -12,4 +12,8 @@
 #define VECTOR_PTR_RO(x) ((const SEXP*) DATAPTR_RO(x))
 #endif
 
+#ifndef INTEGER64_PTR
+#define INTEGER64_PTR(x) ((long long*) REAL(x))
+#endif
+
 #endif
